## Summary

<!-- Brief description of the changes. -->

## Motivation

<!-- Why is this change needed? Link to relevant issue(s). -->

Fixes AgentAnycast/agentanycast#

## Changes

-

## Testing

- [ ] `ruff check .` passes
- [ ] `ruff format --check .` passes
- [ ] `pytest tests/ -v` passes
- [ ] Manually verified (if applicable)

## Checklist

- [ ] Type hints on all public APIs
- [ ] Self-reviewed the diff
- [ ] Updated documentation (if applicable)
